AnimationPreferences class

Use this class to setup preferences inside your AnimationDefinitions AnimatorWidget uses preferences to automatically apply offset, duration, autoPlay and add an AnimationStatusListener.

Constructors

AnimationPreferences({double magnitude = 1, Duration offset = Duration.zero, Duration duration = const Duration(seconds: 1), AnimationPlayStates? autoPlay = AnimationPlayStates.Forward, AnimationStatusListener? animationStatusListener})
Constructor with defaults.
const

Properties

animationStatusListener → AnimationStatusListener?
Adds an AnimationStatusListener to the generated AnimationController inside an AnimatorInstance
final
autoPlay → AnimationPlayStates?
Defines autoPlay for the AnimationDefinition, AnimatorWidget uses this to initially start an animation upon render.
final
duration → Duration
Defines a duration for the AnimationDefinition
final
hashCode → int
The hash code for this object.
no setterinherited
magnitude → double
Defines the magnitude of the animation (1.0 = 100%, 0.5 = 50%, etc.)
final
offset → Duration
Defines an offset for the AnimationDefinition.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Duration? offset, Duration? duration, AnimationPlayStates? autoPlay, AnimationStatusListener? animationStatusListener}) → AnimationPreferences
Shorthand to initialize a copy with one or more changed parameters.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited