RollOutAnimation class

Used by RollOut widget. Note: You can also pass this into an InOutAnimation widget to define the in/out animation.

Inheritance

Constructors

RollOutAnimation({AnimationPreferences preferences = const AnimationPreferences()})

Properties

hashCode → int
The hash code for this object.
no setterinherited
needsScreenSize → bool
When true, instructs AnimatorWidget to preRender the child without animation and extracts the screen-size in order to supply it to AnimationDefinition.build() in the next render.
finalinherited
needsWidgetSize → bool
When true, instructs AnimatorWidget to preRender the child without animation and extracts the child's size in order to supply it to AnimationDefinition.build() in the next render.
finalinherited
preferences → AnimationPreferences
Pass AnimationPreferences to setup offset, duration, autoPlay and add an AnimationStatusListener
finalinherited
preRenderOpacity → double
Sets the visibility of the child during the preRender when needsWidgetSize or needsScreenSize is set to true. Use this property to prevent 'flickering' when rendering in-animations.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context, Animator animator, Widget child) → Widget
AnimatorWidget calls build to retrieve the animated Widget. The extracted Animator from the getDefinition phase is injected to supply a controller and the Animation objects. Example: @override Widget build(BuildContext context, Animator animator, Widget child) { return FadeTransition( opacity: animation.get('opacity'), child: child, ); }
override
getDefinition({Size? screenSize, Size? widgetSize}) → Map<String, TweenList>
AnimatorWidget calls getDefinition to gather the animation. Animations are defined using named TweenLists using a Map<String, TweenList>. Example: @override Map<String, TweenList> getDefinition({Size screenSize, Size widgetSize}) { return { "opacity": TweenList
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited